# audit-cuos
Generate activity reports for functionaries on the English Wikipedia.

__Author:__ Molly White<br />
__License:__ [MIT](http://opensource.org/licenses/MIT)<br/>
__Version:__ 0.1<br />

##To use
1. Download this project to your computer (either clone from git, or [download the .zip](https://github.com/molly/audit-cuos/archive/master.zip) and extract it to a folder)
2. Change to the project directory.
3. Run `easy_install .` ([download instructions for easy_install](https://pythonhosted.org/setuptools/easy_install.html#installing-easy-install))
4. Run `python3 audit.py`
5. When prompted, enter your English Wikipedia username and password (this will not be saved anywhere). You must have checkuser and oversight privileges to run this script.
6. The output will be saved to a file in your current directory.
